<?php

namespace App\Controller\Web;

class ProductController
{
    /**
     * $config.
     *
     * @var array
     */
    protected $config;

    public function __construct()
    {
        $this->config = config('product');
    }

    /**
     * 首頁
     */
    public function index($level_1_class_id = null, $level_2_class_id = null)
    {
        // 分類
        $class = \DB::table($this->config['class_table'])->where([['act', 1], ['del', 0]])->orderBy('class_id', 'asc')->orderBy('no', 'desc')->orderBy('id', 'asc')->get(['id', 'class_id', 'name']);

        $product_class = $class->keyBy('id');
        $product_class_tree = $class->groupBy('class_id');

        // 頁數
        $page = \Request::query('page', 1);
        $page_show = 10;

        // 預設
        empty($level_1_class_id) and $level_1_class_id = $product_class_tree[0][0]['id'];
        empty($level_2_class_id) and $level_2_class_id = $product_class_tree[$level_1_class_id][0]['id'];

        // 判斷存在以及檢查是否為正確父子關係
        if (!isset($product_class[$level_1_class_id])) {
            $level_1_class_id = null;
            $level_2_class_id = null;
        } elseif (!isset($product_class[$level_2_class_id]) || !($product_class[$level_2_class_id]['class_id'] == $level_1_class_id)) {
            $level_2_class_id = null;
        }

        $product = \DB::table($this->config['table'])
                      // ->select('id', 'class_id', 'name', 'pic')
                      ->where([['class_id', $level_2_class_id], ['act', 1], ['del', 0]])
                      ->orderBy('no', 'desc')
                      ->orderBy('id', 'asc')
                      ->paginate($page_show, ['*'], 'page', $page)
                      ->withPath(base_path(\Request::path()))
                      ->appends(\Request::query());

        $view = \View::make("web.{$this->config['folder']}.index", compact('product', 'product_class', 'product_class_tree', 'level_1_class_id', 'level_2_class_id','class'))->render();

        return \Response::create($view)->send();
    }

    /**
     * 搜尋結果頁面
     */
    public function search_list()
    {
        // 分類
        $class = \DB::table($this->config['class_table'])->where([['act', 1], ['del', 0]])->orderBy('class_id', 'asc')->orderBy('no', 'desc')->orderBy('id', 'asc')->get(['id', 'class_id', 'name']);

        $product_class = $class->keyBy('id');

        if (!empty(\Request::query('keyword', ''))) {
            $product = \DB::table($this->config['table'])
                          ->select('id', 'class_id', 'name', 'pic')
                          ->where([
                                ['act', 1],
                                ['del', 0],
                          ])
                          ->where([
                                ['name', 'like' , '%' . \Request::query('keyword', '') . '%'] ,
                                ['info', 'like' , '%' . \Request::query('keyword', '') . '%', 'or' ] ,
                          ])
                          ->orderBy('no', 'desc')
                          ->orderBy('id', 'asc')
                          ->get()
                          ->transform(function ($row, $key) use ($product_class) {
                              $row['level_2_class_id'] = $row['class_id'];
                              $row['level_1_class_id'] = $product_class[$row['class_id']]['class_id'];

                              return $row;
                          });
        } else {
            $product = [];
        }

        $view = \View::make("web.{$this->config['folder']}.search-list", compact('product', 'product_class'))->render();

        return \Response::create($view)->send();
    }

    /**
     * 資料內頁
     */
    public function detail($level_1_class_id, $level_2_class_id, $id)
    {
        // 分類
        $class = \DB::table($this->config['class_table'])->where([['act', 1], ['del', 0]])->orderBy('no', 'desc')->orderBy('id', 'asc')->get(['id', 'class_id', 'name']);

        $product_class = $class->keyBy('id');
        $product_class_tree = $class->groupBy('class_id');

        // Data
        $product = \DB::table($this->config['table'])->where([['id', $id], ['act', 1], ['del', 0]])->first();

        if (!isset($product_class[$level_1_class_id])) {
            return redirect(\Session::get('lang').'/'.'product')->withErrors('無此筆資料')->send();
        } elseif (!isset($product_class[$level_2_class_id]) || !($product_class[$level_2_class_id]['class_id'] == $level_1_class_id)) {
            return redirect(\Session::get('lang').'/'."product/{$level_1_class_id}")->withErrors('無此筆資料')->send();
        } elseif (empty($product) || !($product['class_id'] == $level_2_class_id)) {
            return redirect(\Session::get('lang').'/'."product/{$level_1_class_id}/{$level_2_class_id}")->withErrors('無此筆資料')->send();
        }

        // 多圖
        $pics = \DB::table($this->config['pics_table'])->where([['pid', $id], ['del', 0]])->orderBy('no', 'desc')->orderBy('id', 'asc')->get();

        $view = \View::make("web.{$this->config['folder']}.detail", compact('product', 'product_class', 'product_class_tree', 'pics', 'level_1_class_id', 'level_2_class_id'))->render();

        return \Response::create($view)->send();
    }
}